==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/items/tool/TrackToolItems.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.tool;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;
import org.herac.tuxguitar.gui.SystemImages;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.track.AddTrackAction;
import org.herac.tuxguitar.gui.actions.track.RemoveTrackAction;
import org.herac.tuxguitar.gui.items.ItemContainer;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class TrackToolItems implements ItemContainer{
    public static final String NAME = "TRACK_ITEMS";
    
    private TablatureEditor tablatureEditor;
    private ToolBar toolBar;   
    private ToolItem add;
    private ToolItem remove;
    
    public TrackToolItems(TablatureEditor tablatureEditor,ToolBar toolBar){
        this.tablatureEditor = tablatureEditor;
        this.toolBar = toolBar;
    }
   
    public void showItems(){                       
        this.add = new ToolItem(toolBar, SWT.PUSH);        
        this.add.setImage(SystemImages.TRACK_ADD);
        this.add.addSelectionListener(TuxGuitar.instance().getAction(AddTrackAction.NAME));

        this.remove = new ToolItem(toolBar, SWT.PUSH);        
        this.remove.setImage(SystemImages.TRACK_REMOVE);
        this.remove.addSelectionListener(TuxGuitar.instance().getAction(RemoveTrackAction.NAME));        
        
        this.loadProperties();
    }

    public void loadProperties(){
        this.add.setToolTipText(TuxGuitar.getProperty("track.add"));
        this.remove.setToolTipText(TuxGuitar.getProperty("track.remove"));
    }
    
    public void update(){
    }
}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/items/tool/TrackToolItems.java <==
/*
 * Created on 02-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.items.tool;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.ToolBar;
import org.eclipse.swt.widgets.ToolItem;
import org.herac.tuxguitar.gui.SystemImages;
import org.herac.tuxguitar.gui.TuxGuitar;
import org.herac.tuxguitar.gui.actions.track.AddTrackAction;
import org.herac.tuxguitar.gui.actions.track.RemoveTrackAction;
import org.herac.tuxguitar.gui.items.ToolItems;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class TrackToolItems extends ToolItems{
    public static final String NAME = "track.items";
    
    private ToolBar toolBar;   
    private ToolItem add;
    private ToolItem remove;
    
    public TrackToolItems(){
    	super(NAME);
    }
   
    public void showItems(ToolBar toolBar){
    	this.toolBar = toolBar;     
    	
        this.add = new ToolItem(toolBar, SWT.PUSH);        
        this.add.setImage(SystemImages.TRACK_ADD);
        this.add.addSelectionListener(TuxGuitar.instance().getAction(AddTrackAction.NAME));

        this.remove = new ToolItem(toolBar, SWT.PUSH);        
        this.remove.setImage(SystemImages.TRACK_REMOVE);
        this.remove.addSelectionListener(TuxGuitar.instance().getAction(RemoveTrackAction.NAME));        
        
        this.loadProperties();
    }

    public void loadProperties(){
        this.add.setToolTipText(TuxGuitar.getProperty("track.add"));
        this.remove.setToolTipText(TuxGuitar.getProperty("track.remove"));
    }
    
    public void update(){
    }
}
